.comparison__child-object {
  border-top: 1px dashed #e6e6e6;
  padding: 1em;
}

.comparison__child-object:first-child {
  border-top: 0;
}

.comparison__child-object.addition {
  background-color: #ebffeb;
}

.comparison__child-object.deletion {
  background-color: #ffebeb;
}

.comparison__list {
  margin-top: 0;
  margin-bottom: -1em;
}

.comparison span.addition {
  background-color: #a6f3a6;
}

.comparison span.deletion {
  background-color: #f8cbcb;
}

.comparison .preview-image {
  display: inline-block;
}

.comparison .preview-image.addition, .comparison .preview-image.deletion {
  padding: 5px;
  margin-right: 5px;
  border-style: solid;
  border-width: 1px;
}

.comparison .preview-image.addition {
  background-color: #ebffeb;
  border-color: #a6f3a6;
}

.comparison .preview-image.deletion {
  background-color: #ffebeb;
  border-color: #f8cbcb;
}

.comparison .preview-image img {
  display: block;
}
