{% load i18n wagtailadmin_tags %}

<ul class="breadcrumb">
    {% for page in page.get_ancestors %}
        {% if page.is_root %}
            <li class="home"><a href="{% url 'wagtailadmin_choose_page_child' page.id %}{% querystring p=None %}" class="navigate-pages icon icon-home text-replace">{% trans 'Home' %}</a></li>
        {% else %}
            <li><a href="{% url 'wagtailadmin_choose_page_child' page.id %}{% querystring p=None %}" class="navigate-pages">{{ page.get_admin_display_title }}</a></li>
        {% endif %}
    {% endfor %}
</ul>
