{% extends "wagtailadmin/base.html" %}
{% load wagtailimages_tags %}
{% load i18n %}
{% block titletag %}{% trans "Add user" %}{% endblock %}
{% block content %}

    {% trans "Add user" as add_user_str %}
    {% include "wagtailadmin/shared/header.html" with title=add_user_str merged=1 tabbed=1 icon="user" %}

    <ul class="tab-nav merged">
        <li class="active"><a href="#account">{% trans "Account" %}</a></li>
        <li><a href="#roles">{% trans "Roles" %}</a></li>
    </ul>

    <form action="{% url 'wagtailusers_users:add' %}" method="POST" novalidate{% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
        <div class="tab-content">
            {% csrf_token %}
            <section id="account" class="active nice-padding">
                <ul class="fields">
                    {% block fields %}
                        {% if form.separate_username_field %}
                            {% include "wagtailadmin/shared/field_as_li.html" with field=form.username_field %}
                        {% endif %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=form.email %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=form.first_name %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=form.last_name %}
                        {% block extra_fields %}{% endblock extra_fields %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=form.password1 %}
                        {% include "wagtailadmin/shared/field_as_li.html" with field=form.password2 %}
                    {% endblock fields %}

                    <li><a href="#roles" class="button lowpriority tab-toggle icon icon-arrow-right-after" />{% trans "Roles" %}</a></li>
                </ul>
            </section>
            <section id="roles" class="nice-padding">
                <ul class="fields">
                    {% include "wagtailadmin/shared/field_as_li.html" with field=form.is_superuser %}
                    {% include "wagtailadmin/shared/field_as_li.html" with field=form.groups %}
                    <li><input type="submit" value='{% trans "Add user" %}' class="button" /></li>
                </ul>
            </section>
        </div>
    </form>
{% endblock %}
