from __future__ import absolute_import, unicode_literals


class RemovedInWagtail112Warning(DeprecationWarning):
    pass


removed_in_next_version_warning = RemovedInWagtail112Warning


class RemovedInWagtail113Warning(PendingDeprecationWarning):
    pass
