{% extends "wagtailadmin/widgets/chooser.html" %}

{% block chooser_class %}snippet-chooser{% endblock %}

{% block chosen_state_view %}
    <span class="title">{{ item }}</span>
{% endblock %}

{% block edit_chosen_item_url %}{% if item %}{% url 'wagtailsnippets:edit' model_opts.app_label model_opts.model_name item.id %}{% endif %}{% endblock %}
