@import 'wagtailadmin/scss/variables';

.content header {
    margin-bottom: 0;
}


.result-list {
    margin-bottom: 0;
}

.listing {

    td,
    th {
        vertical-align: top;
    }

    thead th.sorted a {
        color: $color-teal;
    }

    tbody {
        overflow: auto;

        tr:hover ul.actions {
            visibility: visible;
        }

        tr > td { 
            background-color: inherit;
            
            a.edit-obj { 
                color: inherit;
                font-weight: 600; 
            }
        }

    }
}


.changelist-filter {
    padding: 0 15px;

    h2 {
        background-color: #fafafa;
        font-size: 13px;
        line-height: 31px;
        margin-top: 0;
        padding-left: 8px;
        border-bottom: 1px solid #e6e6e6;
    }

    h3 {
        font-size: 12px;
        margin-bottom: 0;
    }

    ul {
        padding-left: 0;
        margin-bottom: 25px;
    }

    li {
        list-style-type: none;
        margin: 0 0 4px;
        padding-left: 0;
    }

    a {
        font-family: Open Sans,Arial,sans-serif;
        border-radius: 3px;
        width: auto;
        line-height: 1.2em;
        padding: 8px 12px;
        font-size: 0.9em;
        font-weight: normal;
        vertical-align: middle;
        display: block;
        background-color: #fff;
        border: 1px solid #43b1b0;
        color: #43b1b0;
        text-decoration: none;
        text-transform: uppercase;
        position: relative;
        overflow: hidden;
        outline: none;
        box-sizing: border-box;
        -webkit-font-smoothing: auto;
        -moz-appearance: none;
        -moz-box-sizing: border-box;

        &:hover {
            background-color: #358c8b;
            border-color: #358c8b;
            color: #fff;
        }
    }

    li.selected a {
        color: #fff !important;
        border-color: #43b1b0 !important;
        background-color: #43b1b0;
    }
}


.no-search-results {
    margin-top: 30px;

    h2 {
        padding-top: 0.3em;
        margin-bottom: 0.3em;
    }

    img {
        float: left;
        margin: 0 15px 15px 0;
        width: 50px;
   }
}


div.pagination {
    margin-top: 3em;
    border-top: 1px dashed #d9d9d9;
    padding: 2em 1em 0;

    ul {
        margin-top: -1.25em;
    }
}


p.no-results {
    margin: 30px 1em 0;
}


@media screen and (min-width: 50em) {
    .changelist-filter {
        float: right;
        padding: 0 1.5%;
    }

    .result-list {
        padding: 0 1.5% 0 0;

        &.col12 {
            padding-right: 0;

            tbody td:last-child {
                padding-right: 50px;
            }
        }

        tbody th:first-child {
            padding-left: 50px;
        }
    }

    div.pagination {
        padding-left: 50px;
        padding-right: 50px;
    }

    div.pagination.col9 {
        width: 73.5%;
    }

    p.no-results {
        margin: 30px 50px 0;
    }
}


@media screen and (min-width: 1200px) {
    .result-list.col9 {
        width: 79%;
    }

    .changelist-filter {
        width: 21%;
    }

    div.pagination.col9 {
        width: 77.5%;
    }
}
