{% load i18n %}
<table class="listing">
    <col />
    <col  />
    <col width="16%" />
    <thead>
        <tr class="table-headers">
            <th>{% trans "Title" %}</th>
        </tr>
    </thead>
    <tbody>
        {% for snippet in items %}
            <tr>
                <td class="title">
                    {% if choosing %}
                        <h2><a class="snippet-choice" href="{% url 'wagtailsnippets:chosen' model_opts.app_label model_opts.model_name snippet.id %}">{{ snippet }}</a></h2>
                    {% else %}
                        <h2><a href="{% url 'wagtailsnippets:edit' model_opts.app_label model_opts.model_name snippet.id %}">{{ snippet }}</a></h2>
                    {% endif %}
                </td>
            </tr>
        {% endfor %}
    </tbody>
</table>
