{% load i18n wagtailadmin_tags %}
<section class="panel summary nice-padding">
    <h2 class="visuallyhidden">{% trans "Site summary" %}</h2>
    <ul class="stats">
        {% for item in summary_items %}
            {{ item.render }}
        {% endfor %}
    </ul>
</section>
