{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{{ view.page_title }}{% endblock %}

{% block content %}
    {% include "wagtailadmin/shared/header.html" with title=view.page_title subtitle=view.get_page_subtitle icon=view.header_icon %}

    <div class="nice-padding">
        <p>{{ view.confirmation_message }}</p>
        <form action="{{ view.get_delete_url }}" method="POST">
            {% csrf_token %}
            <input type="submit" value="{% trans 'Yes, delete' %}" class="button serious" />
        </form>
    </div>
{% endblock %}
